@@ -21,10 +21,12 @@ ThetaQuantiles <- function(FF, alpha.grid, lbd, ubd) {
          }
          
          ngrid <- length(alpha.grid)
-         qtheta <- rep(0, ngrid)
-         for(i in 1:ngrid)  {
-             qtheta[i] <- uniroot(ff, lower = lbd, upper = ubd, alpha = alpha.grid[i])$root
-         }
+         #qtheta <- rep(0, ngrid)
+         qtheta <- mroot(ff, lower=rep(lbd, ngrid), upper=rep(ubd, ngrid), 
+                         alpha = alpha.grid)$root 
+         #for(i in 1:ngrid)  {
+         #    qtheta[i] <- uniroot(ff, lower = lbd, upper = ubd, alpha = alpha.grid[i])$root
+         #}
     }    
     return(qtheta)   
 }
